==> haskell-binary-orphans-0.1.8.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-orphans
version: 0.1.8.0
id: binary-orphans-0.1.8.0-9IUvikmutr3L9EjILdLLoi
key: binary-orphans-0.1.8.0-9IUvikmutr3L9EjILdLLoi
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-orphans#readme
synopsis: Orphan instances for binary
description:
    `binary-orphans` defines orphan instances for types in some popular packages.
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
indefinite: False
exposed-modules:
    Data.Binary.Orphans
abi: 5a89a2375e7fc89f3471a364bac4b24b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/binary-orphans-0.1.8.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/binary-orphans-0.1.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/binary-orphans-0.1.8.0
hs-libraries: HSbinary-orphans-0.1.8.0-9IUvikmutr3L9EjILdLLoi
depends:
    base-4.10.0.0 aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y binary-0.8.5.1
    case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    text-binary-0.2.1.1-G3nCBzz6ndV3NX4aa2ahAI
    vector-binary-instances-0.2.3.5-DWvVOI4GHrECD2ZJqrEThD
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=c240e412bac64503e37397debf06fa14
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=c277093fa16e707f51e09b45510f1326
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG=ef0c2166834103b504bc3792a7d2c177
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             text-binary-0.2.1.1-G3nCBzz6ndV3NX4aa2ahAI=81ae9c8c1f756754a85e71a5edc296ed
             vector-binary-instances-0.2.3.5-DWvVOI4GHrECD2ZJqrEThD=23f06a84a106196e9d65f622e61b1fe6
haddock-interfaces: /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock
haddock-html: /usr/share/doc/haskell-binary-orphans/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-orphans-0.1.8.0-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-orphans
version: 0.1.8.0
id: binary-orphans-0.1.8.0-DhrjyFzHSTn1mxmgXqKFqS
key: binary-orphans-0.1.8.0-DhrjyFzHSTn1mxmgXqKFqS
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-orphans#readme
synopsis: Orphan instances for binary
description:
    `binary-orphans` defines orphan instances for types in some popular packages.
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
indefinite: False
exposed-modules:
    Data.Binary.Orphans
abi: d74afe526b683afa166d617208810eb3
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/binary-orphans-0.1.8.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/binary-orphans-0.1.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/binary-orphans-0.1.8.0
hs-libraries: HSbinary-orphans-0.1.8.0-DhrjyFzHSTn1mxmgXqKFqS
depends:
    base-4.10.0.0 aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq binary-0.8.5.1
    case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    text-binary-0.2.1.1-G3nCBzz6ndV3NX4aa2ahAI
    vector-binary-instances-0.2.3.5-DWvVOI4GHrECD2ZJqrEThD
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=8b90ef7c46d906c8047345fb433e32fe
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             case-insensitive-1.2.0.10-G6p6xuzQuZQOyTREOVUmI=c240e412bac64503e37397debf06fa14
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=c277093fa16e707f51e09b45510f1326
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=a0445f54fa186d288e1223c9f60f5307
             tagged-0.8.5-7Kuk6etyDBjGPRKMYpsbFG=ef0c2166834103b504bc3792a7d2c177
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             text-binary-0.2.1.1-G3nCBzz6ndV3NX4aa2ahAI=81ae9c8c1f756754a85e71a5edc296ed
             vector-binary-instances-0.2.3.5-DWvVOI4GHrECD2ZJqrEThD=23f06a84a106196e9d65f622e61b1fe6
haddock-interfaces: /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock
haddock-html: /usr/share/doc/haskell-binary-orphans/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
